@@ -30,8 +30,8 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <klocale.h>
-#include <kglobal.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
 #include <kdebug.h>
 #include <kurldrag.h>
 
@@ -204,7 +204,7 @@ bool ItemPtrVector::item_cmp(RegisterItem* i1, RegisterItem* i2)
         break;
 
       default:
-        qDebug("Invalid sort key %d", *it);
+        tqDebug("Invalid sort key %d", *it);
         break;
     }
 
@@ -340,7 +340,7 @@ void GroupMarker::paintRegisterCell(TQPainter* painter, int row, int /* col */,
 
     font.setBold(false);
     painter->setFont(font);
-    painter->drawText(cellRect, TQt::AlignVCenter | TQt::AlignCenter, KGlobal::locale()->formatDate(sortPostDate(), true));
+    painter->drawText(cellRect, TQt::AlignVCenter | TQt::AlignCenter, TDEGlobal::locale()->formatDate(sortPostDate(), true));
   }
 
   painter->restore();
@@ -449,7 +449,7 @@ TypeGroupMarker::TypeGroupMarker(Register* parent, CashFlowDirection dir, MyMone
       }
       break;
     default:
-      qDebug("Unknown CashFlowDirection %d for TypeGroupMarker constructor", dir);
+      tqDebug("Unknown CashFlowDirection %d for TypeGroupMarker constructor", dir);
       break;
   }
 }
@@ -511,7 +511,7 @@ void RegisterToolTip::maybeTip(const TQPoint& pos)
     return;
 
   TQPoint cpos = m_register->viewportToContents(pos);
-  // qDebug("RegisterToolTip::mayBeTip(%d,%d)", cpos.x(), cpos.y());
+  // tqDebug("RegisterToolTip::mayBeTip(%d,%d)", cpos.x(), cpos.y());
   int row = m_register->rowAt(cpos.y());
   int col = m_register->columnAt(cpos.x());
   RegisterItem* item = m_register->itemAtRow(row);
@@ -521,8 +521,8 @@ void RegisterToolTip::maybeTip(const TQPoint& pos)
   TQPoint relPos(cpos.x() - m_register->columnPos(0), cpos.y() - m_register->rowPos(item->startRow()));
   row = row - item->startRow();
 
-  // qDebug("row = %d, col = %d", row, col);
-  // qDebug("relpos = %d,%d", relPos.x(), relPos.y());
+  // tqDebug("row = %d, col = %d", row, col);
+  // tqDebug("relpos = %d,%d", relPos.x(), relPos.y());
   TQString msg;
   TQRect rect;
   if(!item->maybeTip(cpos, row, col, rect, msg))
@@ -625,15 +625,15 @@ void Register::dragMoveEvent(TQDragMoveEvent* event)
 
 void Register::dropEvent(TQDropEvent* event)
 {
-  qDebug("Register::dropEvent");
+  tqDebug("Register::dropEvent");
   if ( KURLDrag::canDecode(event) ) {
     event->ignore();
     Transaction* t = dropTransaction(event->pos());
     if(t && !t->isScheduled()) {
-      qDebug("Drop was ok");
+      tqDebug("Drop was ok");
       KURL::List urls;
       KURLDrag::decode(event, urls);
-      qDebug("List is '%s'", urls.toStringList().join(";").data());
+      tqDebug("List is '%s'", urls.toStringList().join(";").data());
       event->accept();
     }
   }
@@ -667,7 +667,7 @@ void Register::slotAutoColumnSizing(int section)
       }
       size += TQString("%1").arg((columnWidth(i) * 100) / w);
     }
-    qDebug("size = %s", size.data());
+    tqDebug("size = %s", size.data());
     m_account.setValue("kmm-ledger-column-width", size);
   }
 #endif
@@ -1180,7 +1180,7 @@ void Register::updateRegister(bool forceUpdateRowHeight)
 int Register::rowHeightHint(void) const
 {
   if(!m_rowHeightHint) {
-    qDebug("Register::rowHeightHint(): m_rowHeightHint is zero!!");
+    tqDebug("Register::rowHeightHint(): m_rowHeightHint is zero!!");
   }
   return m_rowHeightHint;
 }
@@ -1189,11 +1189,11 @@ void Register::paintCell(TQPainter* painter, int row, int col, const TQRect& r,
 {
   // determine the item that we need to paint in the row and call it's paintRegisterCell() method
   if((row < 0) || ((unsigned)row > m_itemIndex.size())) {
-    qDebug("Register::paintCell: row %d out of bounds %d", row, (int)m_itemIndex.size());
+    tqDebug("Register::paintCell: row %d out of bounds %d", row, (int)m_itemIndex.size());
     return;
   }
 
-  // qDebug("paintCell(%d,%d)", row, col);
+  // tqDebug("paintCell(%d,%d)", row, col);
   RegisterItem* const item = m_itemIndex[row];
   item->paintRegisterCell(painter, row - item->startRow(), col, r, selected, cg);
 }
@@ -1374,7 +1374,7 @@ void Register::adjustColumn(int col)
 
   // check for date column
   if(col == DateColumn) {
-    TQString txt = KGlobal::locale()->formatDate(TQDate(6999,12,29), true);
+    TQString txt = TDEGlobal::locale()->formatDate(TQDate(6999,12,29), true);
     int nw = cellFontMetrics.width(txt+"  ");
     w = TQMAX( w, nw );
   } else {
@@ -1415,7 +1415,7 @@ void Register::repaintItems(RegisterItem* first, RegisterItem* last)
   if(last == 0)
     last = first;
 
-  // qDebug("repaintItems from row %d to row %d", first->startRow(), last->startRow()+last->numRowsRegister()-1);
+  // tqDebug("repaintItems from row %d to row %d", first->startRow(), last->startRow()+last->numRowsRegister()-1);
 
   // the following code is based on code I found in
   // TQTable::cellGeometry() and TQTable::updateCell()  (ipwizard)
@@ -1877,7 +1877,7 @@ TQWidget* Register::cellWidget(int row, int col) const
 
   if(row > numRows() - 1 || col > numCols() - 1) {
     if(numRows() && numCols())
-      qWarning("Register::cellWidget(%d,%d) out of bounds (%d,%d)", row, col, numRows(), numCols());
+      tqWarning("Register::cellWidget(%d,%d) out of bounds (%d,%d)", row, col, numRows(), numCols());
     return 0;
   }
 
@@ -1897,7 +1897,7 @@ TQWidget* Register::cellWidget(int row, int col) const
 void Register::insertWidget(int row, int col, TQWidget* w)
 {
   if(row < 0 || col < 0 || row > numRows() - 1 || col > numCols() - 1) {
-    qWarning("Register::insertWidget(%d,%d) out of bounds", row, col);
+    tqWarning("Register::insertWidget(%d,%d) out of bounds", row, col);
     return;
   }
 
@@ -1908,7 +1908,7 @@ void Register::insertWidget(int row, int col, TQWidget* w)
 void Register::clearCellWidget(int row, int col)
 {
   if(row < 0 || col < 0 || row > numRows() - 1 || col > numCols() - 1) {
-    qWarning("Register::clearCellWidget(%d,%d) out of bounds", row, col);
+    tqWarning("Register::clearCellWidget(%d,%d) out of bounds", row, col);
     return;
   }
 
@@ -2243,7 +2243,7 @@ Transaction* Register::transactionFactory(Register *parent, const MyMoneyTransac
     case MyMoneyAccount::MoneyMarket:
     case MyMoneyAccount::Stock:
     default:
-      qDebug("Register::transactionFactory: invalid accountTypeE %d", parent->account().accountType());
+      tqDebug("Register::transactionFactory: invalid accountTypeE %d", parent->account().accountType());
       break;
   }
   return t;
@@ -2270,8 +2270,8 @@ void Register::addGroupMarkers(void)
       lastMonth = thisMonth.addMonths(-1);
       yesterday = today.addDays(-1);
       // a = TQDate::dayOfWeek()      todays weekday (1 = Monday, 7 = Sunday)
-      // b = KLocale::weekStartDay() first day of week (1 = Monday, 7 = Sunday)
-      weekStartOfs = today.dayOfWeek() - KGlobal::locale()->weekStartDay();
+      // b = TDELocale::weekStartDay() first day of week (1 = Monday, 7 = Sunday)
+      weekStartOfs = today.dayOfWeek() - TDEGlobal::locale()->weekStartDay();
       if(weekStartOfs < 0) {
         weekStartOfs = 7 + weekStartOfs;
       }
